==> checkstyle_6.15.orig.tar.xz: checkstyle-6.15/src/it/resources/com/google/checkstyle/test/chapter7javadoc/rule72thesummaryfragment/InputCorrectSummaryJavaDocCheck.java <==
package com.google.checkstyle.test.chapter7javadoc.rule72thesummaryfragment;

/**
 * Some Javadoc A {@code Foo} is a simple Javadoc.
 */
class InputCorrectSummaryJavaDocCheck {

    /**
     * Some Javadoc This method returns.
     */
    public static final byte NUL = 0;
    
    /**
     * As of JDK 1.1, replaced by {@link #setBounds(int,int,int,int)}.
     */
    void foo3() {}
    
    /**
     * @throws Exception if an error occurs.
     */
    void foo4() throws Exception {}
    
    /** An especially This method returns short bit of Javadoc. */
    void foo5() {}

    /**
     * An especially short
     * bit of Javadoc. This method returns.
     */
    void foo6() {}

    /** 
     * <a href="mailto:vlad@htmlbook.ru"/> 
     */
     class InnerInputCorrectJavaDocParagraphCheck {

         /**
          * foooo@foooo.
          */
        public static final byte NUL = 0;
        
        /** 
         * Some java@doc.
         * This method returns.
         */
        public static final byte NUL_2 = 0;

        /**
         * Returns the customer ID. This method returns
         */
        int getId() {return 666;}
        
        /**
         * <a href="mailto:vlad@htmlbook.ru"/>.
         */
        void foo2() {}
        
        /**
         * As of JDK 1.1,
         * replaced by {@link #setBounds(int,int,int,int)}. This method returns.
         */
        void foo3() {}
        
        /**
         * @throws Exception if an error occurs.
         */
        void foo4() throws Exception {}
        
        /** 
         * JAXB Provider Use Only: Provides partial default
         * implementations for some of the javax.xml.bind interfaces.
         */
        void foo5() {}

        /**
         * An especially short (int... A) bit of Javadoc. This
         * method returns
         */
        void foo6() {}
    }

     /**
      * Some
      * javadoc. A {@code Foo} is a simple Javadoc.
      * 
      * Some Javadoc. A {@code Foo}
      * is a simple Javadoc.
      */
    InnerInputCorrectJavaDocParagraphCheck anon = new InnerInputCorrectJavaDocParagraphCheck() {

        /**
         * JAXB 1.0 only default validation event handler.
         */
        public static final byte NUL = 0;

        /**
         * Returns the current state.
         * This method returns.
         */
        boolean emulated(String s) {return false;}
        
        /**
         * As of JDK 1.1, replaced by {@link #setBounds(int,int,int,int)}.
         */
        void foo3() {}
        
        /**
         * @throws Exception if an error occurs.
         */
        void foo4() throws Exception {}
        
        /** An especially short bit of Javadoc. */
        void foo5() {}

        /**
         * An especially short bit of Javadoc.
         */
        void foo6() {}
        
        /**
         * Some Javadoc. This method returns some javadoc.
         */
        boolean emulated() {return false;}
        
        /**
         * Some Javadoc. This method returns some javadoc. Some Javadoc.
         */
        boolean emulated1() {return false;}
        
        /**
         * @return Some Javadoc the customer ID.
         */
        int geId() {return 666;} 
    };
}

==> checkstyle_8.8.orig.tar.xz: checkstyle-8.8/src/it/resources/com/google/checkstyle/test/chapter7javadoc/rule72thesummaryfragment/InputCorrectSummaryJavaDocCheck.java <==
package com.google.checkstyle.test.chapter7javadoc.rule72thesummaryfragment;

/**
 * Some Javadoc A {@code Foo} is a simple Javadoc.
 */
class InputCorrectSummaryJavaDocCheck {

    /**
     * Some Javadoc This method returns.
     */
    public static final byte NUL = 0;
    
    /**
     * As of JDK 1.1, replaced by {@link #setBounds(int,int,int,int)}.
     */
    void foo3() {}
    
    /**
     * This is valid.
     * @throws Exception if an error occurs.
     */
    void foo4() throws Exception {}
    
    /** An especially This method returns short bit of Javadoc. */
    void foo5() {}

    /**
     * An especially short
     * bit of Javadoc. This method returns.
     */
    void foo6() {}

    /**
     * This is valid.
     * <a href="mailto:vlad@htmlbook.ru"/>
     */
     class InnerInputCorrectJavaDocParagraphCheck {

         /**
          * foooo@foooo.
          */
        public static final byte NUL = 0;
        
        /** 
         * Some java@doc.
         * This method returns.
         */
        public static final byte NUL_2 = 0;

        /**
         * Returns the customer ID. This method returns.
         */
        int getId() {return 666;}
        
        /**
         * This is valid.
         * <a href="mailto:vlad@htmlbook.ru"/>.
         */
        void foo2() {}
        
        /**
         * As of JDK 1.1,
         * replaced by {@link #setBounds(int,int,int,int)}. This method returns.
         */
        void foo3() {}
        
        /**
         * This is valid.
         * @throws Exception if an error occurs.
         */
        void foo4() throws Exception {}
        
        /** 
         * JAXB Provider Use Only: Provides partial default
         * implementations for some of the javax.xml.bind interfaces.
         */
        void foo5() {}

        /**
         * An especially short (int... A) bit of Javadoc. This
         * method returns.
         */
        void foo6() {}
    }

     /**
      * Some
      * javadoc. A {@code Foo} is a simple Javadoc.
      * 
      * Some Javadoc. A {@code Foo}
      * is a simple Javadoc.
      */
    InnerInputCorrectJavaDocParagraphCheck anon = new InnerInputCorrectJavaDocParagraphCheck() {

        /**
         * JAXB 1.0 only default validation event handler.
         */
        public static final byte NUL = 0;

        /**
         * Returns the current state.
         * This method returns.
         */
        boolean emulated(String s) {return false;}
        
        /**
         * As of JDK 1.1, replaced by {@link #setBounds(int,int,int,int)}.
         */
        void foo3() {}
        
        /**
         * This is valid.
         * @throws Exception if an error occurs.
         */
        void foo4() throws Exception {}
        
        /** An especially short bit of Javadoc. */
        void foo5() {}

        /**
         * An especially short bit of Javadoc.
         */
        void foo6() {}
        
        /**
         * Some Javadoc. This method returns some javadoc.
         */
        boolean emulated() {return false;}
        
        /**
         * Some Javadoc. This method returns some javadoc. Some Javadoc.
         */
        boolean emulated1() {return false;}
        
        /**
         * This is valid.
         * @return Some Javadoc the customer ID.
         */
        int geId() {return 666;} 
    };
}
